<?php

namespace App\Listeners;

use App\Events\NotifyEvent;
use App\Repositories\CourseRepository;
use App\Repositories\NotificationInstanceRepository;
use App\Repositories\NotificationRepository;

class NotifyListener
{
    /**
     * Create the event listener.
     */
    public function __construct()
    {
        //
    }

    /**
     * Handle the event.
     */
    public function handle(NotifyEvent $event): void
    {
        $notification = NotificationRepository::query()->where('type', $event->type)->first();

        if (!$notification->is_enabled) {
            return;
        }

        $course = CourseRepository::find(
            $event->metadata['course_id']
        );

        // Send notification to all enrolled users
        foreach ($course->enrollments as $enrollment) {
            $notificationText = str_replace('%course_title%', $enrollment->course->title, $notification->content);
            $notificationText = str_replace('%user_name%', $enrollment->user->name, $notificationText);

            // Create notification instance
            NotificationInstanceRepository::create([
                'notification_id' => $notification->id,
                'recipient_id' => $enrollment->user->id,
                'metadata' => json_encode($event->metadata),
                'content' => $notificationText,
            ]);

            $url = 'https://fcm.googleapis.com/fcm/send';

            $tokens = $enrollment->user->fcmDeviceTokens()->pluck('token')->toArray();

            $data = [
                "registration_ids" => $tokens,
                "notification" => [
                    "title" => $notificationText,
                    "body" => $notificationText,
                ]
            ];
            $encodedData = json_encode($data);
            $headers = [
                'Authorization:key=' . config('app.fcm_server_key'),
                'Content-Type: application/json',
            ];

            // Request Firebase Cloud Messaging Server
            $ch = curl_init();
            curl_setopt($ch, CURLOPT_URL, $url);
            curl_setopt($ch, CURLOPT_POST, true);
            curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
            curl_setopt($ch, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_1);
            // Disabling SSL Certificate support temporarly
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
            curl_setopt($ch, CURLOPT_POSTFIELDS, $encodedData);
            // Execute post
            $result = curl_exec($ch);
            if ($result === FALSE) {
                die('Curl failed: ' . curl_error($ch));
            }
            // Close connection
            curl_close($ch);
        }
    }
}
