<?php

namespace App\Models;

// use Illuminate\Contracts\Auth\MustVerifyEmail;

use Illuminate\Database\Eloquent\Casts\Attribute;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\Relations\HasOne;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Illuminate\Support\Facades\Storage;
use Laravel\Passport\HasApiTokens;

class User extends Authenticatable
{
    use HasApiTokens, HasFactory, Notifiable, SoftDeletes;

    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */
    protected $guarded = ['id'];

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * The attributes that should be cast.
     *
     * @var array<string, string>
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
        'password' => 'hashed',
    ];

    public function profilePicture(): BelongsTo
    {
        return $this->belongsTo(Media::class, 'media_id');
    }

    public function profilePicturePath(): Attribute
    {
        $profilePicture = asset('media/blank-user.png');

        if ($this->profilePicture && Storage::exists($this->profilePicture->src)) {
            $profilePicture = Storage::url($this->profilePicture->src);
        }

        return Attribute::make(
            get: fn () => $profilePicture,
        );
    }

    public function instructor(): HasOne
    {
        return $this->hasOne(Instructor::class);
    }

    public function reviews(): HasMany
    {
        return $this->hasMany(Review::class);
    }

    public function enrollments(): HasMany
    {
        return $this->hasMany(Enrollment::class);
    }

    public function resetPasswords(): HasMany
    {
        return $this->hasMany(ResetPassword::class);
    }

    public function favouriteCourses(): BelongsToMany
    {
        return $this->belongsToMany(Course::class, 'user_courses');
    }

    public function viewedContents(): HasMany
    {
        return $this->hasMany(UserContentView::class);
    }

    public function transactions(): HasMany
    {
        return $this->hasMany(Transaction::class);
    }

    public function fcmDeviceTokens(): HasMany
    {
        return $this->hasMany(FcmDeviceToken::class);
    }
}
