<?php

namespace App\Repositories;

use Abedin\Boiler\Repositories\Repository;
use App\Models\Media;
use Illuminate\Http\UploadedFile;
use Illuminate\Support\Facades\Storage;

class MediaRepository extends Repository
{

    /**
     * base method
     *
     * @method model()
     */
    public static function model()
    {
        return Media::class;
    }

    public static function storeByRequest(UploadedFile $file, $path, $type = null): Media
    {
        $src = Storage::put('/' . trim($path, '/'), $file, 'public');

        return self::create([
            'extension' => $file->extension(),
            'src' => $src,
            'path' => $path,
            'type' => $type,
        ]);
    }

    public static function updateByRequest(UploadedFile $file, Media $media, $path, $type = null): Media
    {
        $src = Storage::put('/' . trim($path, '/'), $file, 'public');

        if (Storage::exists($media->src)) {
            Storage::delete($media->src);
        }

        self::update($media, [
            'extension' => $file->extension(),
            'src' => $src,
            'path' => $path,
            'type' => $type,
        ]);

        return $media;
    }

    public static function updateOrCreateByRequest(UploadedFile $file, $media = null, $path, $type = null): Media
    {
        $src = Storage::put('/' . trim($path, '/'), $file, 'public');

        if ($media && Storage::exists($media->src)) {
            Storage::delete($media->src);
        }

        $media = self::query()->updateOrCreate([
            'id' => $media?->id ?? 0
        ], [
            'extension' => $file->extension(),
            'src' => $src,
            'path' => $path,
            'type' => $type,
        ]);

        return $media;
    }
}
