<?php

namespace App\Repositories;

use Abedin\Boiler\Repositories\Repository;
use App\Enum\MediaTypeEnum;
use App\Http\Requests\SettingUpdateRequest;
use App\Models\Setting;

class SettingRepository extends Repository
{
    public static function model()
    {
        return Setting::class;
    }

    public static function updateByRequest(SettingUpdateRequest $request, Setting $setting)
    {
        if ($setting->logo) {
            $logo = $request->hasFile('logo') ? MediaRepository::updateByRequest(
                $request->file('logo'),
                $setting->logo,
                'setting/logo',
                MediaTypeEnum::IMAGE
            ) : $setting->logo;
        } else {
            $logo = $request->hasFile('logo') ? MediaRepository::storeByRequest(
                $request->file('logo'),
                'setting/logo',
                MediaTypeEnum::IMAGE
            ) : null;
        }

        if ($setting->favicon) {
            $favicon = $request->hasFile('favicon') ? MediaRepository::updateByRequest(
                $request->file('favicon'),
                $setting->favicon,
                'setting/favicon',
                MediaTypeEnum::IMAGE
            ) : $setting->favicon;
        } else {
            $favicon = $request->hasFile('favicon') ? MediaRepository::storeByRequest(
                $request->file('favicon'),
                'setting/favicon',
                MediaTypeEnum::IMAGE
            ) : null;
        }

        return self::update($setting, [
            'logo_id' => $logo ? $logo->id : null,
            'favicon_id' => $favicon ? $favicon->id : null,
            'footer_text' => $request->footer_text ?? $setting->footer_text,
            'currency_position' => $request->currency_position ?? $setting->currency_position,
        ]);
    }
}
