<?php

namespace App\Services;

use App\Interfaces\PaymentGatewayInterface;
use Srmklive\PayPal\Services\PayPal as PayPalClient;

class PaypalPayment implements PaymentGatewayInterface
{
    public function processPayment($amount, array $data,  array $configInput)
    {
        $config = [
            "mode" => $configInput['mode'],
            "sandbox" => [
                "client_id" => $configInput['client_id'],
                "client_secret" => $configInput['client_secret'],
                "app_id" => $configInput['app_id']
            ],
            "live" => [
                "client_id" => $configInput['client_id'],
                "client_secret" => $configInput['client_secret'],
                "app_id" => $configInput['app_id']
            ],
            "payment_action" => "Sale",
            "currency" => config('app.currency'),
            "notify_url" => "",
            "locale" => "en_US",
            "validate_ssl" => true
        ];

        session(['configSuccess' => $config]);

        $provider = new PayPalClient();
        $provider->setApiCredentials($config);
        $provider->getAccessToken();

        $response = $provider->createOrder([
            "intent" => "CAPTURE",
            "application_context" => [
                "return_url" => route('paypal.payment.success', $data['identifier']),
                "cancel_url" => route('paypal.payment.cancel'),
            ],
            "purchase_units" => [
                0 => [
                    "amount" => [
                        "currency_code" => config('app.currency'),
                        "value" => $amount
                    ]
                ]
            ]
        ]);

        if (isset($response['id']) && $response['id'] != null) {
            foreach ($response['links'] as $links) {
                if ($links['rel'] == 'approve') {
                    return redirect()->away($links['href']);
                }
            }
        }

        return response()->json(['message' => 'Payment failed'], 400);
    }
}
