@extends('layouts.app')

@section('title', $app_setting['name'] . ' | Chapter Update')

@section('content')
    <!-- ****Body-Section***** -->
    <div class="app-main-outer">
        <div class="app-main-inner">
            <div class="page-title-actions px-3 d-flex">
                <nav aria-label="breadcrumb">
                    <ol class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{ route('admin.dashboard') }}">Dashboard</a></li>
                        <li class="breadcrumb-item"><a href="{{ route('course.index') }}">Course</a></li>
                        <li class="breadcrumb-item"><a
                                href="{{ $chapter->course ? route('chapter.index', $chapter->course?->id) : route('chapter.select_course') }}">Chapter</a>
                        </li>
                        <li class="breadcrumb-item active" aria-current="page">Edit</li>
                    </ol>
                </nav>
            </div>
            <div class="row" id="deleteTableItem">
                <div class="col-md-12">
                    @if ($errors->any())
                        <div class="alert alert-danger">
                            <ul class="m-0">
                                @foreach ($errors->all() as $error)
                                    <li>{{ $error }}</li>
                                @endforeach
                            </ul>
                        </div>
                    @endif
                    <div class="main-card card d-flex h-100 flex-column">
                        <div class="card-body">
                            <h5 class="card-title py-2">Edit Chapter</h5>
                            <form action="{{ route('chapter.update', $chapter->id) }}" method="POST"
                                enctype="multipart/form-data">
                                @csrf @method('PUT')
                                <div class="row">
                                    <div class="col-4">
                                        <div class="form-group">
                                            <label class="form-label" for="categoryInput">Course</label>
                                            <select id="categoryInput"
                                                class="form-select select2bs4 select2-hidden-accessible" name="course_id"
                                                aria-hidden="true">
                                                @foreach ($courses as $course)
                                                    <option value="{{ $course->id }}"
                                                        {{ $course->id === $chapter->course?->id ? 'selected="selected"' : '' }}>
                                                        {{ $course->title }}</option>
                                                @endforeach
                                            </select>
                                        </div>
                                    </div>

                                    <div class="col-4">
                                        <div class="mb-3">
                                            <label for="titleInput" class="form-label">Chapter Title</label>
                                            <input type="text" name="title" required class="form-control"
                                                value="{{ $chapter->title }}" id="titleInput">
                                        </div>
                                    </div>
                                    <div class="col-4">
                                        <div class="mb-3">
                                            <label for="titleInput" class="form-label">Sequence</label>
                                            <input type="number" required value="{{ $chapter->serial_number }}"
                                                min="1" name="serial_number" class="form-control" id="titleInput"
                                                value="{{ $course->chapters()->count() + 1 }}">
                                        </div>
                                    </div>

                                    <div class="col-12">
                                        <label for="" class="form-label">Contents</label>
                                        <div id="contentsWrapper">
                                            @foreach ($chapter->contents as $content)
                                                <div id="content{{ $loop->index }}" class="row border p-3 mb-3">
                                                    <input name="contents[{{ $loop->index }}][content_id]" type="hidden"
                                                        value="{{ $content->id }}">
                                                    <div class="col-4">
                                                        <div class="mb-3">
                                                            <label for="titleInput" class="form-label">Content Title</label>
                                                            <input type="text" required
                                                                name="contents[{{ $loop->index }}][title]"
                                                                class="form-control" id="titleInput"
                                                                value="{{ $content->title }}">
                                                        </div>
                                                    </div>

                                                    {{-- <div class="col-2">
                                                        <div class="mb-3">
                                                            <label for="titleInput" class="form-label">Content Type</label>
                                                            <select class="form-select"
                                                                name="contents[{{ $loop->index }}][type]">
                                                                <option
                                                                    {{ $content->type->value === 'image' ? 'selected' : '' }}
                                                                    value="image">Image</option>
                                                                <option
                                                                    {{ $content->type->value === 'video' ? 'selected' : '' }}
                                                                    value="video">Video</option>
                                                                <option
                                                                    {{ $content->type->value === 'audio' ? 'selected' : '' }}
                                                                    value="audio">Audio</option>
                                                                <option
                                                                    {{ $content->type->value === 'document' ? 'selected' : '' }}
                                                                    value="document">Document</option>
                                                            </select>
                                                        </div>
                                                    </div> --}}

                                                    <div class="col-2">
                                                        <div class="mb-3">
                                                            <label for="titleInput" class="form-label">Sequence</label>
                                                            <input type="number" required min="1"
                                                                value="{{ $content->serial_number }}"
                                                                name="contents[{{ $loop->index }}][serial_number]"
                                                                class="form-control" id="titleInput">
                                                        </div>
                                                    </div>

                                                    <div class="col-3">
                                                        <div class="mb-3">
                                                            <label for="fileInput" class="form-label">Current
                                                                File:
                                                                <strong>{{ '...' . substr(str_replace($content->media->path . '/', '', $content->media->src), -20) }}</strong>
                                                            </label>
                                                            <div class="input-group">
                                                                <div class="custom-file">
                                                                    <input name="contents[{{ $loop->index }}][media]"
                                                                        type="file"
                                                                        class="custom-file-input form-control"
                                                                        id="fileInput">
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>

                                                    <div class="col-1">
                                                        <div class="mb-3">
                                                            <label for="fileInput" class="form-label">&nbsp;</label>
                                                            <div class="form-check">
                                                                <input name="contents[{{ $loop->index }}][is_forwardable]"
                                                                    class="form-check-input" type="checkbox"
                                                                    @if ($content->is_forwardable) checked @endif>
                                                                <label class="form-check-label">Forwardable</label>
                                                            </div>
                                                        </div>
                                                    </div>

                                                    <div class="col-2">
                                                        <label class="form-label">&nbsp;</label>
                                                        <div>
                                                            <button type="button" class="btn btn-danger mb-4"
                                                                onclick="removeContentItem({{ $loop->index }})">-
                                                                Remove Content</button>
                                                        </div>
                                                    </div>
                                                </div>
                                            @endforeach
                                        </div>

                                        <button type="button" class="btn bgBlue btn-dipBlue mb-4"
                                            onclick="addContentItem()">+
                                            Add Content
                                            Item</button>
                                    </div>
                                    <div class="col-12">
                                        <button type="submit" class="btn bgBlue btn-dipBlue">Update</button>
                                    </div>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <!-- ****End-Body-Section**** -->
    </div>

@endsection
@push('scripts')
    <script>
        var contentCounter = contentsWrapper.childElementCount;

        function addContentItem() {
            var contentRow = `<div id="content${contentCounter}" class="row border p-3 mb-3">
                                    <div class="col-4">
                                        <div class="mb-3">
                                            <label class="form-label">Content Title</label>
                                            <input type="text" required name="contents[${contentCounter}][title]" class="form-control" placeholder="Enter content title">
                                        </div>
                                    </div>

                                    <div class="col-2">
                                        <div class="mb-3">
                                            <label class="form-label">Sequence</label>
                                            <input type="number" min="1" required value="${contentCounter}" name="contents[${contentCounter}][serial_number]" class="form-control">
                                        </div>
                                    </div>

                                    <div class="col-3">
                                        <div class="mb-3">
                                            <label class="form-label">Upload File</label>
                                            <div class="input-group">
                                                <div class="custom-file">
                                                    <input name="contents[${contentCounter}][media]" required type="file" class="custom-file-input form-control">
                                                </div>
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-1">
                                        <div class="mb-3">
                                            <label for="fileInput" class="form-label">&nbsp;</label>
                                            <div class="form-check">
                                                <input name="contents[${contentCounter}][is_forwardable]"
                                                    class="form-check-input" type="checkbox">
                                                <label class="form-check-label">Forwardable</label>
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-2">
                                        <label class="form-label">&nbsp;</label>
                                        <div>
                                            <button type="button" class="btn btn-danger mb-4"
                                                onclick="removeContentItem(${contentCounter})">-
                                                Remove Content</button>
                                        </div>
                                    </div>
                                </div>`

            $('#contentsWrapper').append(contentRow);

            ++contentCounter;
        }

        function removeContentItem(elementNumber) {
            $(`#content${elementNumber}`).remove();
        }
    </script>
@endpush
